package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(`*``!````Z)D``#0`````U````@``!#0`(``)
M`"@`&P`:``$``'#DS0``Y$T!`.1-`0`(````"`````0````$````!@```#0`
M```T@```-(```"`!```@`0``!0````0````#````5`$``%2!``!4@0``$P``
M`!,````$`````0````$``````````(````"```#PS0``\,T```4`````@```
M`0```.3.``#DS@$`Y,X!`(0"``"P$@``!@````"````"````\,X``/#.`0#P
MS@$`$`$``!`!```&````!`````0```!H`0``:($``&B!```@````(`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71DY,X`
M`.3.`0#DS@$`'`$``!P!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````"````!@```!````!A````>````!``````
M`````````&0`````````;````&H``````````````%0```!9````4````'``
M``!8````+`````````!#````=`````(````P````8P```!<````%````2@``
M````````````-@```%<```!>```````````````5````;P```%(```!,````
M`````'(```!U````<P```'<`````````*P````````!A`````````&(```!3
M```````````````*````(`````````!:```````````````Y````#@```&T`
M``!I```````````````9`````````%L``````````````$4`````````*```
M`$(```!&````8````#0````^```````````````(````(P```%4```!<````
M=@```%$```!)````/0```!$````````````````````\````70````````!E
M````:P```#\```!6````-P```'$`````````````````````````````````
M````````````````````````````````````````````````````````````
M``T``````````````````````````````!0`````````$P``````````````
M#``````````=```````````````&``````````,````>````&@``````````
M```````````````````````````````I````)P``````````````+P``````
M```!````&P```!(`````````,0`````````$````````````````````````
M```````````````````````E```````````````````````````````8````
M,@```#H````A````#P```$0`````````,P```#4`````````)````$T````J
M````'P````D````<```````````````N````(@```#@```!'````2```````
M``!!````+0``````````````7P`````````F````3@```#L```!+````0```
M`!8`````````:````&<```!F``````````````````````````<```!/````
M;@````L`````````````````````````"@$``$S1`0``````(``6`)D$``#8
MH0``&````!(`#`"J!```/*4``(`````2``P`$0```#26````````$@```&P#
M``!`E@```````!(````H````3)8````````2````>@,``%B6````````$@``
M`+<$``"<ZP``!````!(`#`"^`P``9)8````````2````#@$``.B9````````
M$@`,`#(```!PE@```````!(````+!```?)8````````2````/0```(B6````
M````$@```%```````````````"````!?```````````````@````<P```*"6
M````````$@```(<```"LE@```````!(```"9````N)8````````2````70,`
M`,26````````$@```,$$```4\0```````!(`#0#'!```,.```+`&```2``P`
MW00``.RH``"(````$@`,`.L$``#$H```%`$``!(`#`"F````T)8````````2
M````KP```-R6````````$@```+T```#HE@```````!(````!!0``O*4``'P!
M```2``P`#04``+C/``!<````$@`,`*,#``#TE@```````!(```#-`````)<`
M```````2````*`4```S<``",````$@`,`.0#```,EP```````!(````T!0``
M9-$!``0````1`!8`VP```!B7````````$@```(L%``!T]```;ED``!$`#@!#
M!0``)/$```0````1``X`Y@```"27````````$@```-0#```PEP```````!(`
M``#Z````/)<````````2````+0```$B7````````$@```!X#``!4EP``````
M`!(```#D`@``8)<````````2````_0,``&R7````````$@````@!``!,T0$`
M`````!``%@`5`0``>)<````````2````=P0``&C1`0``````$`#Q_R<!``"$
MEP```````!(````U`0``D)<````````2````10$``)R7````````$@```%8!
M``"HEP```````!(```!G`0``M)<````````2````G`,``,"7````````$@``
M`%@$``#L30$``````!``\?]E`P``S)<````````2````MP,``-B7````````
M$@```!\%``#DEP```````!(```!2!0``D)H``%@````2``P`=@$``/"7````
M````$@```)$$``"4X0$``````!``\?]:!0``H.L``'0````2``P`A00``)3A
M`0``````$`#Q_Q\$``!HT0$`!````"$`%P#^`@``_)<````````2````A0$`
M``B8````````$@```*H#```4F````````!(```#X`@``()@````````2````
MDP$``"R8````````$@```%0#```XF````````!(```#&`P``1)@````````2
M````)P0``%"8````````$@```&L$``!HT0$``````!``\?^.`P``7)@`````
M```2````H0$``&B8````````$@```!8#``!TF````````!(````/`@``@)@`
M```````2````A@0``)3A`0``````$`#Q_Y4#``",F````````!(```"Q`P``
MF)@````````2````K0$``*28````````$@```+X!``"PF````````!(```#U
M`P``O)@````````2````+0,``,B8````````$@```&H%``#`WP``<````!(`
M#``>!```:-$!``0````A`!<`T`$``-28````````$@```.4!``#@F```````
M`!(```!?!```E.$!```````0`/'_AP,``.R8````````$@````,"``#XF```
M`````!(```#;`P``!)D````````2````%@(``!"9````````$@```!T$``!H
MT0$`!````!$`%P"&!0``8-$!``0````1`!8`,00``!R9````````$@```","
M```HF0```````!(```#K`P``-)D````````2````-0(``&S1`0`3````$0`7
M`)4%``!PT@````@``!(`#`!D!```:-$!```````0`/'_3`,``$"9````````
M$@```$0"``!,F0```````!(```"B!0``!-$``&P!```2``P`M`4``/"A``!,
M`P``$@`,`'(#``!8F0```````!(```!/`@``9)D````````2````7@(``'"9
M````````$@```$H$``#D30$``````!``\?]P`@``?)D````````2````@`,`
M`(B9````````$@```(4"``"4F0```````!(````$!```H)D````````2````
M/P,``*R9````````$@````4#``"XF0```````!(```#!!0``.*<``+0!```2
M``P`1`,``,29````````$@```!@$``!DYP``"`0``!(`#`!4!0``#)8`````
M```2``H`E@(``-"9````````$@```*T"``#<F0```````!(`````;&EB<&5R
M;"YS;RXU+C$P`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]F<F5E`'!E
M<FQ?<&%R<V4`4&5R;%]A=&9O<FM?=6YL;V-K`%]?9VUO;E]S=&%R=%]?`%]*
M=E]296=I<W1E<D-L87-S97,`4&5R;%])979A;%]R;V]T7W!T<@!097)L7TEI
M;E]E=F%L7W!T<@!097)L7TEO<%]P='(`<&5R;%]R=6X`4&5R;%]A=E]S:&EF
M=`!097)L7V=V7V9E=&-H<'8`4&5R;%]S=E]S971P=@!P97)L7V%L;&]C`%!E
M<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%]D;W5N=VEN9`!?7V1A=&%?<W1A<G0`
M4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S>7-?=&5R;0!B;V]T7T1Y;F%,;V%D
M97(`4&5R;%]A=&9O<FM?;&]C:P!097)L7VYE=UA37V9L86=S`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?879?9F5T8V@`<&5R;%]D97-T
M<G5C=`!097)L7VUG7W-E=`!097)L7TEP87)S97)?<'1R`%!E<FQ?27-T871B
M=69?<'1R`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!E<FQ?9&5S=')U
M8W1?;&5V96Q?<'1R`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7VYE=U-6<'8`
M4&5R;%])=&]P7V5N=E]P='(`4$Q?;65M;W)Y7W=R87``4&5R;%]N97=84P!0
M97)L7W-Y<U]I;FET,P!097)L7T=T:')?:V5Y7W!T<@!097)L7TEE>&ET7V9L
M86=S7W!T<@!097)L7TEC;VUP8W9?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R
M7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB
M<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T
M`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E
M9VES=&5R7V%T9F]R:P!E>&ET`'-P<FEN=&8`<W1R;F-M<`!C;&]S961I<@!S
M=')N8W!Y`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?7V5X:61X7W-T87)T`%]?97AI9'A?96YD`%]E9&%T80!?
M7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`
M<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?24]?<W1D:6Y?
M=7-E9`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?4$%2
M7T-,14%24U1!0TL`;F%M95]L;V%D7VUE7S(`<&%R7VUK=&UP9&ER`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?
M,BXT`````0`!``$````"`````@`!``(``0````(``````````````````@`!
M``$``0`!``````````$``0`"`````0`"``$````!``$````"`````@`#``,`
M`@`!`````0```````````````@`!``(``@`"``$````!``$``0`"``,````"
M``,````"``(``@`!``(````#``(``0`"``(```````(``@`!``(```````$`
M`@````(````"``$``@````(````!``$``@````$``0`"```````!`````@``
M``(``@`#``$``@`!``$```````$``0#4`@``$````"`````4:6D-```#`,X%
M`````````0`!`",#```0`````````!1I:0T```(`S@4```````!(T0$`%0X`
M`&C1`0`47```;-$!`!1A```,T`$`%@0``!#0`0`6!0``%-`!`!8&```8T`$`
M%@<``!S0`0`6"0``(-`!`!8+```DT`$`%@P``"C0`0`6#0``+-`!`!8.```P
MT`$`%A```#30`0`6$0``.-`!`!82```\T`$`%A,``$#0`0`6&```1-`!`!89
M``!(T`$`%AH``$S0`0`6'0``4-`!`!8>``!4T`$`%B```%C0`0`6(@``7-`!
M`!8E``!@T`$`%B8``&30`0`6)P``:-`!`!8H``!LT`$`%BD``'#0`0`6*@``
M=-`!`!8K``!XT`$`%BT``'S0`0`6+P``@-`!`!8P``"$T`$`%C$``(C0`0`6
M,@``C-`!`!8S``"0T`$`%C0``)30`0`6-@``F-`!`!8W``"<T`$`%C@``*#0
M`0`6.@``I-`!`!8_``"HT`$`%D```*S0`0`600``L-`!`!9"``"TT`$`%D,`
M`+C0`0`61```O-`!`!9%``#`T`$`%D8``,30`0`62```R-`!`!9)``#,T`$`
M%DH``-#0`0`62P``U-`!`!9-``#8T`$`%DX``-S0`0`63P``X-`!`!90``#D
MT`$`%E$``.C0`0`64@``[-`!`!95``#PT`$`%E8``/30`0`66```^-`!`!99
M``#\T`$`%EH```#1`0`66P``!-$!`!9>```(T0$`%E\```S1`0`68```$-$!
M`!9D```4T0$`%F4``!C1`0`6:```'-$!`!9I```@T0$`%FH``"31`0`6;```
M*-$!`!9M```LT0$`%FX``##1`0`6;P``--$!`!9P```XT0$`%G$``#S1`0`6
M<P``0-$!`!9V``!$T0$`%G<```3@+>4$T$WB`0$`ZP30C>(`@+WH!.`MY03@
MG^4.X(_@"/"^Y=`Y`0``QH_B$\J,XM#YO.4`QH_B$\J,XLCYO.4`QH_B$\J,
MXL#YO.4`QH_B$\J,XKCYO.4`QH_B$\J,XK#YO.4`QH_B$\J,XJCYO.4`QH_B
M$\J,XJ#YO.4`QH_B$\J,XICYO.4`QH_B$\J,XI#YO.4`QH_B$\J,XHCYO.4`
MQH_B$\J,XH#YO.4`QH_B$\J,XGCYO.4`QH_B$\J,XG#YO.4`QH_B$\J,XFCY
MO.4`QH_B$\J,XF#YO.4`QH_B$\J,XECYO.4`QH_B$\J,XE#YO.4`QH_B$\J,
MXDCYO.4`QH_B$\J,XD#YO.4`QH_B$\J,XCCYO.4`QH_B$\J,XC#YO.4`QH_B
M$\J,XBCYO.4`QH_B$\J,XB#YO.4`QH_B$\J,XACYO.4`QH_B$\J,XA#YO.4`
MQH_B$\J,X@CYO.4`QH_B$\J,X@#YO.4`QH_B$\J,XOCXO.4`QH_B$\J,XO#X
MO.4`QH_B$\J,XNCXO.4`QH_B$\J,XN#XO.4`QH_B$\J,XMCXO.4`QH_B$\J,
MXM#XO.4`QH_B$\J,XLCXO.4`QH_B$\J,XL#XO.4`QH_B$\J,XKCXO.4`QH_B
M$\J,XK#XO.4`QH_B$\J,XJCXO.4`QH_B$\J,XJ#XO.4`QH_B$\J,XICXO.4`
MQH_B$\J,XI#XO.4`QH_B$\J,XHCXO.4`QH_B$\J,XH#XO.4`QH_B$\J,XGCX
MO.4`QH_B$\J,XG#XO.4`QH_B$\J,XFCXO.4`QH_B$\J,XF#XO.4`QH_B$\J,
MXECXO.4`QH_B$\J,XE#XO.4`QH_B$\J,XDCXO.4`QH_B$\J,XD#XO.4`QH_B
M$\J,XCCXO.4`QH_B$\J,XC#XO.4`QH_B$\J,XBCXO.4`QH_B$\J,XB#XO.4`
MQH_B$\J,XACXO.4`QH_B$\J,XA#XO.4`QH_B$\J,X@CXO.4`QH_B$\J,X@#X
MO.4`QH_B$\J,XOCWO.4`QH_B$\J,XO#WO.4`QH_B$\J,XNCWO.4`QH_B$\J,
MXN#WO.4`QH_B$\J,XMCWO.4`QH_B$\J,XM#WO.4`QH_B$\J,XLCWO.4`QH_B
M$\J,XL#WO.4`QH_B$\J,XKCWO.4`QH_B$\J,XK#WO.4`QH_B$\J,XJCWO.4`
MQH_B$\J,XJ#WO.4`QH_B$\J,XICWO.4`QH_B$\J,XI#WO.4`QH_B$\J,XHCW
MO.4`QH_B$\J,XH#WO.4`QH_B$\J,XGCWO.4`QH_B$\J,XG#WO.4`QH_B$\J,
MXFCWO.4`QH_B$\J,XF#WO.4DP)_E`+"@XP00G>0-(*#A!"`MY00`+>40`)_E
M$#"?Y03`+>4:___K$/__ZYSK``!DYP``H.L``!0PG^44()_E`S"/X`(0D^<`
M`%'C'O\O`17__^K0-0$`2`$``!`PG^4`(-/E``!2XP$@H`,`(,,%'O\OX7_1
M`0`@`)_E$$`MZ0`PD.4``%/C$("]"!`PG^4``%/C$("]"#/_+^$0@+WH[,X!
M````````2"WI!+"-X@C03>(X,)_E"#`+Y0``H..P___K`#"@X0`PD^4#`*#A
M*/__ZP`PH.$#`*#A%!"?Y10@G^4(,!OEG?__ZP302^(`B+WH*/$``#3Q``"0
MEP```$@MZ02PC>(!VDWB$-!-XD`QG^4$`$OB`Q"`YS@QG^4$$$OB`R"!YS`A
MG^4!.DOB!#!#X@0P0^("`*#A`Q"@X1PAG^5T___K`#"@X0@P"^4(,!OE``!3
MXPL``-H(,!OE`3!#XOP@G^4$P$OB`B",X`,P@N``,-/E``!3XP(``!H(,!OE
M`3!#X@@P"^4(,!OE``!3XQT``-H((!OE`3I+X@0P0^($,$/B`P"@X2\0H.-Z
M___K`#"@X0``4^,3```*``"@XV___^L`,*#A`#"3Y0,`H.'G_O_K`#"@X0,0
MH.$(P!OE;""?Y0$Z2^($,$/B!#!#X@$`H.$$X$OB`A">YP,@H.$,,*#A_O[_
MZP\``.H``*#C6___ZP`PH.$`,)/E`P"@X=/^_^L`,*#A`Q"@X2`@G^4@,)_E
M`0"@X03`2^("$)SG!.!+X@,@GN>Q_O_K!-!+X@"(O>CT[___\.___U#Q``#_
M#P``_.____!(+>D4L(WB"-!-X@!@H.$8$`OE``!6XP,```K0,)_E`#"3Y0``
M4^,!```:`#"@XRP``.H&0*#A````Z@%`A.(`,-3E``!3XP(```H`,-3E/0!3
MX_C__QH$(*#A!C"@X0)P8^"(,)_E`%"3Y1D``.H',*#A!`"@X080H.$#(*#A
M&?__ZP`PH.$``%/C$```&@<PH.$#,(3@`##3Y3T`4^,+```:!2"@X40PG^4`
M,)/E`C!CX$,QH.$#(*#A&#`;Y0`@@^4',*#A`3"#X@,PA.`$``#J!%"%X@!`
ME>4``%3CXO__&@`PH.,#`*#A%-!+XO"(O>AHT0$``$@MZ02PC>(0T$WB$``+
MY0@P2^(0`!OE`Q"@X;G__^L`,*#A`P"@X0302^(`B+WH<$@MZ1"PC>(4T$WB
M(``+Y0%0H.$`,-7E/0!3XP```!H!4(7B!0"@X87^_^L`,*#A&#`+Y1PP2^(@
M`!OE`Q"@X:3__^L`,*#A`T"@X0``5.,2```*!`"@X7G^_^L`(*#A&#`;Y0,`
M4N%.```Z`##5Y0`PQ.4`,-3E``!3XP`PH`,!,*`3_S`#X@%`A.(!4(7B``!3
MX_3__QH`,*#CAP``ZB0RG^4`8)/E`$"@XP$``.H$8(;B`4"$X@`PEN4``%/C
M^O__&@0RG^4`,)/E``!3XQ````KP,9_E`""3Y0(PA.(#,:#A`@"@X0,0H.&Z
M_O_K`#"@X0,@H.',,9_E`""#Y<0QG^4`,)/E``!3XQD``!H`,.#C:0``ZK`Q
MG^4!(*#C`""#Y0(PA.(#,:#A`P"@X7/^_^L`,*#A`V"@X0``5N,!```:`##@
MXUP``.IX,9_E`""3Y00PH.$#,:#A!@"@X0(0H.$#(*#A=/[_ZU@QG^4`8(/E
M````Z@``H.%(,9_E`""3Y00PH.$!,(/B`S&@X0,P@N``(*#C`""#Y00PH.$<
M,`OE````Z@``H.$@0!OE````Z@%`A.(`,-3E``!3XP(```H`,-3E/0!3X_C_
M_QKT,)_E`""3Y1PP&^4#,:#A`V""X`0@H.$@,!OE`C!CX`,@H.$8,!OE`S""
MX`(P@^(#`*#A/O[_ZP`PH.$`,(;E`#"6Y0``4^,!```:`##@XR8``.J@,)_E
M`""3Y1PP&^4#,:#A`S""X`!`D^4```#J`4"$XB`P&^4`,-/E`##$Y0`PU.4`
M`%/C`#"@`P$PH!/_,`/B("`;Y0$@@N(@(`OE``!3XP(```H`,-3E/0!3X^[_
M_QH],*#C`##$Y0%`A.(`,-7E`##$Y0`PU.4``%/C`#"@`P$PH!/_,`/B`4"$
MX@%0A>(``%/C]/__&@`PH.,#`*#A$-!+XG"(O>AHT0$`D.$!`!!(+>D(L(WB
M%-!-XA@`"^4-``#J5#"?Y0`@D^40,!OE`S&@X0-`@N`$,(3B`#"3Y0`PA.4`
M,)3E``!3XP$```H$0(3B]___Z@``H.$0,$OB&``;Y0,0H.'I_O_K`#"@X0``
M4^/J__\:"-!+XA"(O>AHT0$`$$@MZ0BPC>("VDWB%-!-X@`PH.,4,`OE[$"?
MY0'^_^L`(*#A`3I+X@PP0^(,,$/B`P"@X000H.'0,)_E+_[_ZP`PH.$0,`OE
M$#`;Y0``4^,!``"J`#"@XR@``.H!*DOB#"!"X@P@0N(".DOB##!#XA`P0^("
M`*#A`Q"@X0$JH./N_?_K`#"@X1`P"^40,!OE``!3XP$``*H`,*#C%P``ZA`P
M&^4!,(/B`P"@X<+]_^L`,*#A%#`+Y10P&^4``%/C`0``&@`PH.,,``#J$"`;
MY0(Z2^(,,$/B$#!#XA0`&^4#$*#ABOW_ZQ`P&^44(!OE`S""X``@H.,`(,/E
M%#`;Y0,`H.$(T$OB$(B]Z&CQ``!T\0```$@MZ02PC>*W___K`#"@X0,`H.$`
MB+WH$$@MZ0BPC>(!VDWB)-!-XA`SG^4,($OB`P""YP@SG^4,`$OB`Q"`YP`#
MG^7*_O_K`#"@X1`P"^7T,I_E`#"3Y>`BG^4,$$OB`@"1YP,0H.%S_?_K`#"@
MX0``4^,(```*P#*?Y<P"G^4,($OB`Q"2Y\7^_^NL,I_E#`!+X@,PD.>E``#J
MG#*?Y0P02^(#`)'G3OW_ZP`PH.$8,`OEF#*?Y0`PD^6`(I_E#!!+X@(`D><#
M$*#A>/W_ZP`PH.$<,`OEB@``ZAPP&^4`,-/E``!3XP$``!ID,I_E'#`+Y1`P
M&^4``%/C#0``"A``&^4<$!OEKOW_ZP`PH.$``%/C!P``&C0RG^4`,)/E``"@
MXP,0H.%A_?_K`#"@X1PP"^5S``#J'``;Y2G]_^L`,*#A%#`+Y0<``.H4,!OE
M`3!#XA0P"^44,!OE'"`;Y0,P@N``(*#C`"##Y10P&^4!,$/B'"`;Y0,P@N``
M(-/EQ#&?Y0`PD^4`,-/E`P!2X>W__PH4,!OE`2"#XA@P&^4#((+@L#&?Y0,`
M4N$(``#:B#&?Y90!G^4,($OB`Q"2YW?^_^MT,9_E#`!+X@,PD.=7``#JA"&?
MY6PQG^4`P)/E`3I+X@PP0^(0,$/B3!&?Y0P`2^(!$)#G`!"-Y0,`H.$"$*#A
M'"`;Y0PPH.%V_?_K`4I+X@Q`1.(00$3B``"@XUS]_^L`,*#A`#"3Y0,`H.'4
M_/_K`#"@X0,`H.$E_?_K`#"@X00`H.$#$*#A^A$`ZP`PH.$``%/C(P``&@``
MH.-,_?_K`#"@X0`PD^4#`*#AQ/S_ZP`PH.$#`*#A%?W_ZP`PH.$0,)/E#SH#
MX@()4^,5```:`3I+X@PP0^(0,$/B`P"@X0$0H..Y_/_K`#"@X0``4^,,```:
M`3I+X@PP0^(0,$/BA`"?Y0,0H.$T_O_K`3I+X@PP0^(0,$/B`P"@X>?\_^L`
M,*#A$0``ZF`PG^4`,)/E``"@XP,0H.'L_/_K`#"@X1PP"^4<,!OE``!3XW'_
M_QHD,)_E,`"?Y0P@2^(#$)+G'O[_ZQ`PG^4,`$OB`S"0YP,`H.$(T$OB$(B]
MZ.SO___H[___>/$``%31`0"$\0``6-$!`)3Q``#_#P``F/$```2P+>4`L(WB
M%-!-XA``"^40,!OE##`+Y1`P&^4(,`OE#```Z@@P&^4`(-/E2#"?Y0`PD^4`
M,-/E`P!2X0(``!H(,!OE`3"#X@PP"^4(,!OE`3"#X@@P"^4(,!OE`##3Y0``
M4^/N__\:##`;Y0,`H.$`T(OB``B]Z![_+^%4T0$`$$@MZ0BPC>(,T$WB$``+
MY1`P&^4``%/C`P``"A`P&^4`,-/E``!3XP,``!H\`9_EFOS_ZP`PH.%)``#J
M$``;Y6_\_^L`,*#A`3!#XA`@&^4#0(+@````Z@%`1.(0,!OE`P!4X0<``)H`
M(-3E`#&?Y0`PD^4`,-/E`P!2X?7__PH```#J`4!$XA`P&^4#`%3A!0``F@`@
MU.74,)_E`#"3Y0`PT^4#`%+A]?__&A`P&^4#`%3A#P``&@`@U.6P,)_E`#"3
MY0`PT^4#`%+A`P``&I@`G^5Q_/_K`#"@X2```.J,,)_E`#"3Y0,`H.%K_/_K
M`#"@X1H``.H!0$3B$#`;Y0,`5.$%``":`"#4Y6`PG^4`,)/E`##3Y0,`4N'U
M__\*!""@X1`P&^4",&/@`C"#X@$*4^,!``":`#"@XP@``.H$(*#A$#`;Y0(P
M8^`!,(/B(`"?Y1`0&^4#(*#AZ?O_ZQ`PG^4#`*#A"-!+XA"(O>B4\0``5-$!
M`)#1`0``2"WI!+"-XBC03>)<,9_E+,!+X@/@H.$/`+[H#P"LZ`\`ON@/`*SH
M`#">Y;`PS.$\`9_E-_[_ZS@!G^4U_O_K-`&?Y3/^_^LP`9_E,?[_ZRP!G^4O
M_O_K*`&?Y2W^_^LD`9_E*_[_ZR`!G^4I_O_K'`&?Y2?^_^L8`9_E9/W_ZP`P
MH.$(,`OE"#`;Y0``4^,"```*Z`"?Y0@0&^5H_?_K]`"?Y5K]_^L`,*#A"#`+
MY0@P&^4``%/C`@``"MP`G^4($!OE7OW_Z]0`G^50_?_K`#"@X0@P"^4(,!OE
M``!3XP,```J0`)_E"!`;Y53]_^L9``#JK`"?Y47]_^L`,*#A"#`+Y0@P&^4`
M`%/C`P``"F@`G^4($!OE2?W_ZPX``.HL,$OB$3"#X@@P"^4(`!OE=!"?Y0H@
MH.,R_/_K`#"@X0``4^,$```:"#`;Y0HP@^(H`)_E`Q"@X3G]_^L0`)_E2!"?
MY3;]_^L$T$OB`(B]Z&#R``"@\0``L/$``'CQ``"\\0``R/$``-3Q``"$\0``
MX/$``.SQ``#X\0``#/(``"#R```L\@``//(``%#R``!<\@```$@MZ02PC>((
MT$WB;#"?Y0`PD^4!`'/C$P``&F``G^4._?_K`#"@X0@P"^4(,!OE``!3XPD`
M``H(,!OE`##3Y0``4^,%```*"#`;Y0`PT^4P`%/C`0``"@$PH.,```#J`#"@
MXQ0@G^4`,(+E##"?Y0`PD^4#`*#A!-!+X@"(O>A<T0$`O/$```2P+>4`L(WB
M7=]-XG`!"^5P,1OE'#"#XB0P"^4`,*#C*#`+Y1P``.HD,!OE`#"3Y2`P"^4D
M,!OE!#"#XB0P"^4H$!OE(#`;Y0,LH.$@,!OE`S2@X?\X`^(#((+A(#`;Y2,T
MH.'_/`/B`R""X2`P&^4C/*#A`R""X30PG^4!$:#A!`!+X@$0@.`#,('@`""#
MY2@P&^4!,(/B*#`+Y2@P&^4/`%/CW___VA`PH.,H,`OE/@``ZIS^__^9>8):
MH>O9;B@0&^4H,!OE`R!#XB`P'^4"(:#A!,!+X@(@C.`#,(+@`""3Y2@P&^4(
M`$/B0#`?Y0`!H.$$P$OB``",X`,P@.``,)/E`R`BX"@P&^4.`$/B9#`?Y0`!
MH.$$P$OB``",X`,P@.``,)/E`R`BX"@P&^40`$/BB#`?Y0`!H.$$P$OB``",
MX`,P@.``,)/E`R`BX*0P'^4!$:#A!`!+X@$0@.`#,('@`""#Y2@0&^4H(!OE
MQ#`?Y0(AH.$$P$OB`B",X`,P@N``,)/EXR^@X>`P'^4!$:#A!`!+X@$0@.`#
M,('@`""#Y2@P&^4!,(/B*#`+Y2@P&^5/`%/CP/__VG`Q&^4`,)/E'#`+Y7`Q
M&^4$,)/E&#`+Y7`Q&^4(,)/E%#`+Y7`Q&^4,,)/E$#`+Y7`Q&^40,)/E##`+
MY5H_2^((,`OE'#`;Y>,MH.$8$!OE%#`;Y0,0`>`8,!OE`P#@X1`P&^4#,`#@
M`S"!X0,@@N`,,!OE`R""X`@P&^4`,)/E`R""X)`Q'^4#,(+@(#`+Y0@P&^4$
M,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A'!`;Y1@P&^4#$`'@'#`;Y0,`
MX.$4,!OE`S``X`,P@>$#((+@$#`;Y0,@@N`(,!OE`#"3Y0,@@N#T,1_E`S""
MX`PP"^4(,!OE!#"#X@@P"^4<,!OE8S&@X1PP"^4,,!OEXRV@X2`0&^4<,!OE
M`Q`!X"`P&^4#`.#A&#`;Y0,P`.`#,('A`R""X!0P&^4#((+@"#`;Y0`PD^4#
M((+@6#(?Y0,P@N`0,`OE"#`;Y00P@^((,`OE(#`;Y6,QH.$@,`OE$#`;Y>,M
MH.$,$!OE(#`;Y0,0`>`,,!OE`P#@X1PP&^4#,`#@`S"!X0,@@N`8,!OE`R""
MX`@P&^4`,)/E`R""X+PR'^4#,(+@%#`+Y0@P&^4$,(/B"#`+Y0PP&^5C,:#A
M##`+Y10P&^7C+:#A$!`;Y0PP&^4#$`'@$#`;Y0,`X.$@,!OE`S``X`,P@>$#
M((+@'#`;Y0,@@N`(,!OE`#"3Y0,@@N`@,Q_E`S""X!@P"^4(,!OE!#"#X@@P
M"^40,!OE8S&@X1`P"^48,!OEXRV@X100&^40,!OE`Q`!X!0P&^4#`.#A##`;
MY0,P`.`#,('A`R""X"`P&^4#((+@"#`;Y0`PD^4#((+@A#,?Y0,P@N`<,`OE
M"#`;Y00P@^((,`OE%#`;Y6,QH.$4,`OE'#`;Y>,MH.$8$!OE%#`;Y0,0`>`8
M,!OE`P#@X1`P&^4#,`#@`S"!X0,@@N`,,!OE`R""X`@P&^4`,)/E`R""X.@S
M'^4#,(+@(#`+Y0@P&^4$,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A'!`;
MY1@P&^4#$`'@'#`;Y0,`X.$4,!OE`S``X`,P@>$#((+@$#`;Y0,@@N`(,!OE
M`#"3Y0,@@N!,-!_E`S""X`PP"^4(,!OE!#"#X@@P"^4<,!OE8S&@X1PP"^4,
M,!OEXRV@X2`0&^4<,!OE`Q`!X"`P&^4#`.#A&#`;Y0,P`.`#,('A`R""X!0P
M&^4#((+@"#`;Y0`PD^4#((+@L#0?Y0,P@N`0,`OE"#`;Y00P@^((,`OE(#`;
MY6,QH.$@,`OE$#`;Y>,MH.$,$!OE(#`;Y0,0`>`,,!OE`P#@X1PP&^4#,`#@
M`S"!X0,@@N`8,!OE`R""X`@P&^4`,)/E`R""X!0U'^4#,(+@%#`+Y0@P&^4$
M,(/B"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A$!`;Y0PP&^4#$`'@$#`;Y0,`
MX.$@,!OE`S``X`,P@>$#((+@'#`;Y0,@@N`(,!OE`#"3Y0,@@N!X-1_E`S""
MX!@P"^4(,!OE!#"#X@@P"^40,!OE8S&@X1`P"^48,!OEXRV@X100&^40,!OE
M`Q`!X!0P&^4#`.#A##`;Y0,P`.`#,('A`R""X"`P&^4#((+@"#`;Y0`PD^4#
M((+@W#4?Y0,P@N`<,`OE"#`;Y00P@^((,`OE%#`;Y6,QH.$4,`OE'#`;Y>,M
MH.$8$!OE%#`;Y0,0`>`8,!OE`P#@X1`P&^4#,`#@`S"!X0,@@N`,,!OE`R""
MX`@P&^4`,)/E`R""X$`V'^4#,(+@(#`+Y0@P&^4$,(/B"#`+Y1@P&^5C,:#A
M&#`+Y2`P&^7C+:#A'!`;Y1@P&^4#$`'@'#`;Y0,`X.$4,!OE`S``X`,P@>$#
M((+@$#`;Y0,@@N`(,!OE`#"3Y0,@@N"D-A_E`S""X`PP"^4(,!OE!#"#X@@P
M"^4<,!OE8S&@X1PP"^4,,!OEXRV@X2`0&^4<,!OE`Q`!X"`P&^4#`.#A&#`;
MY0,P`.`#,('A`R""X!0P&^4#((+@"#`;Y0`PD^4#((+@"#<?Y0,P@N`0,`OE
M"#`;Y00P@^((,`OE(#`;Y6,QH.$@,`OE$#`;Y>,MH.$,$!OE(#`;Y0,0`>`,
M,!OE`P#@X1PP&^4#,`#@`S"!X0,@@N`8,!OE`R""X`@P&^4`,)/E`R""X&PW
M'^4#,(+@%#`+Y0@P&^4$,(/B"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A$!`;
MY0PP&^4#$`'@$#`;Y0,`X.$@,!OE`S``X`,P@>$#((+@'#`;Y0,@@N`(,!OE
M`#"3Y0,@@N#0-Q_E`S""X!@P"^4(,!OE!#"#X@@P"^40,!OE8S&@X1`P"^48
M,!OEXRV@X100&^40,!OE`Q`!X!0P&^4#`.#A##`;Y0,P`.`#,('A`R""X"`P
M&^4#((+@"#`;Y0`PD^4#((+@-#@?Y0,P@N`<,`OE"#`;Y00P@^((,`OE%#`;
MY6,QH.$4,`OE'#`;Y>,MH.$8$!OE%#`;Y0,0`>`8,!OE`P#@X1`P&^4#,`#@
M`S"!X0,@@N`,,!OE`R""X`@P&^4`,)/E`R""X)@X'^4#,(+@(#`+Y0@P&^4$
M,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A'!`;Y1@P&^4#$`'@'#`;Y0,`
MX.$4,!OE`S``X`,P@>$#((+@$#`;Y0,@@N`(,!OE`#"3Y0,@@N#\.!_E`S""
MX`PP"^4(,!OE!#"#X@@P"^4<,!OE8S&@X1PP"^4,,!OEXRV@X2`0&^4<,!OE
M`Q`AX!@P&^4#,"'@`R""X!0P&^4#((+@"#`;Y0`PD^4#((+@4#D?Y0,P@N`0
M,`OE"#`;Y00P@^((,`OE(#`;Y6,QH.$@,`OE$#`;Y>,MH.$,$!OE(#`;Y0,0
M(>`<,!OE`S`AX`,@@N`8,!OE`R""X`@P&^4`,)/E`R""X*@Y'^4#,(+@%#`+
MY0@P&^4$,(/B"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A$!`;Y0PP&^4#$"'@
M(#`;Y0,P(>`#((+@'#`;Y0,@@N`(,!OE`#"3Y0,@@N``.A_E`S""X!@P"^4(
M,!OE!#"#X@@P"^40,!OE8S&@X1`P"^48,!OEXRV@X100&^40,!OE`Q`AX`PP
M&^4#,"'@`R""X"`P&^4#((+@"#`;Y0`PD^4#((+@6#H?Y0,P@N`<,`OE"#`;
MY00P@^((,`OE%#`;Y6,QH.$4,`OE'#`;Y>,MH.$8$!OE%#`;Y0,0(>`0,!OE
M`S`AX`,@@N`,,!OE`R""X`@P&^4`,)/E`R""X+`Z'^4#,(+@(#`+Y0@P&^4$
M,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A'!`;Y1@P&^4#$"'@%#`;Y0,P
M(>`#((+@$#`;Y0,@@N`(,!OE`#"3Y0,@@N`(.Q_E`S""X`PP"^4(,!OE!#"#
MX@@P"^4<,!OE8S&@X1PP"^4,,!OEXRV@X2`0&^4<,!OE`Q`AX!@P&^4#,"'@
M`R""X!0P&^4#((+@"#`;Y0`PD^4#((+@8#L?Y0,P@N`0,`OE"#`;Y00P@^((
M,`OE(#`;Y6,QH.$@,`OE$#`;Y>,MH.$,$!OE(#`;Y0,0(>`<,!OE`S`AX`,@
M@N`8,!OE`R""X`@P&^4`,)/E`R""X+@['^4#,(+@%#`+Y0@P&^4$,(/B"#`+
MY0PP&^5C,:#A##`+Y10P&^7C+:#A$!`;Y0PP&^4#$"'@(#`;Y0,P(>`#((+@
M'#`;Y0,@@N`(,!OE`#"3Y0,@@N`0/!_E`S""X!@P"^4(,!OE!#"#X@@P"^40
M,!OE8S&@X1`P"^48,!OEXRV@X100&^40,!OE`Q`AX`PP&^4#,"'@`R""X"`P
M&^4#((+@"#`;Y0`PD^4#((+@:#P?Y0,P@N`<,`OE"#`;Y00P@^((,`OE%#`;
MY6,QH.$4,`OE'#`;Y>,MH.$8$!OE%#`;Y0,0(>`0,!OE`S`AX`,@@N`,,!OE
M`R""X`@P&^4`,)/E`R""X,`\'^4#,(+@(#`+Y0@P&^4$,(/B"#`+Y1@P&^5C
M,:#A&#`+Y2`P&^7C+:#A'!`;Y1@P&^4#$"'@%#`;Y0,P(>`#((+@$#`;Y0,@
M@N`(,!OE`#"3Y0,@@N`8/1_E`S""X`PP"^4(,!OE!#"#X@@P"^4<,!OE8S&@
MX1PP"^4,,!OEXRV@X2`0&^4<,!OE`Q`AX!@P&^4#,"'@`R""X!0P&^4#((+@
M"#`;Y0`PD^4#((+@<#T?Y0,P@N`0,`OE"#`;Y00P@^((,`OE(#`;Y6,QH.$@
M,`OE$#`;Y>,MH.$,$!OE(#`;Y0,0(>`<,!OE`S`AX`,@@N`8,!OE`R""X`@P
M&^4`,)/E`R""X,@]'^4#,(+@%#`+Y0@P&^4$,(/B"#`+Y0PP&^5C,:#A##`+
MY10P&^7C+:#A$!`;Y0PP&^4#$"'@(#`;Y0,P(>`#((+@'#`;Y0,@@N`(,!OE
M`#"3Y0,@@N`@/A_E`S""X!@P"^4(,!OE!#"#X@@P"^40,!OE8S&@X1`P"^48
M,!OEXRV@X100&^40,!OE`Q`AX`PP&^4#,"'@`R""X"`P&^4#((+@"#`;Y0`P
MD^4#((+@>#X?Y0,P@N`<,`OE"#`;Y00P@^((,`OE%#`;Y6,QH.$4,`OE'#`;
MY>,MH.$8$!OE%#`;Y0,0(>`0,!OE`S`AX`,@@N`,,!OE`R""X`@P&^4`,)/E
M`R""X-`^'^4#,(+@(#`+Y0@P&^4$,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C
M+:#A'!`;Y1@P&^4#$"'@%#`;Y0,P(>`#((+@$#`;Y0,@@N`(,!OE`#"3Y0,@
M@N`H/Q_E`S""X`PP"^4(,!OE!#"#X@@P"^4<,!OE8S&@X1PP"^4,,!OEXRV@
MX2`0&^4<,!OE`Q`AX!@P&^4#,"'@`R""X!0P&^4#((+@"#`;Y0`PD^4#((+@
M@#\?Y0,P@N`0,`OE"#`;Y00P@^((,`OE(#`;Y6,QH.$@,`OE$#`;Y>,MH.$,
M$!OE(#`;Y0,0(>`<,!OE`S`AX`,@@N`8,!OE`R""X`@P&^4`,)/E`R""X-@_
M'^4#,(+@%#`+Y0@P&^4$,(/B"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A#!`;
MY2`P&^4#$('A$#`;Y0,0`>`,`!OE(#`;Y0,P`.`#,('A`R""X!PP&^4#((+@
M"#`;Y0`PD^4#((+@.#^?Y0,P@N`8,`OE"#`;Y00P@^((,`OE$#`;Y6,QH.$0
M,`OE&#`;Y>,MH.$0$!OE##`;Y0,0@>$4,!OE`Q`!X!``&^4,,!OE`S``X`,P
M@>$#((+@(#`;Y0,@@N`(,!OE`#"3Y0,@@N#0/I_E`S""X!PP"^4(,!OE!#"#
MX@@P"^44,!OE8S&@X10P"^4<,!OEXRV@X100&^40,!OE`Q"!X1@P&^4#$`'@
M%``;Y1`P&^4#,`#@`S"!X0,@@N`,,!OE`R""X`@P&^4`,)/E`R""X&@^G^4#
M,(+@(#`+Y0@P&^4$,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A&!`;Y10P
M&^4#$('A'#`;Y0,0`>`8`!OE%#`;Y0,P`.`#,('A`R""X!`P&^4#((+@"#`;
MY0`PD^4#((+@`#Z?Y0,P@N`,,`OE"#`;Y00P@^((,`OE'#`;Y6,QH.$<,`OE
M##`;Y>,MH.$<$!OE&#`;Y0,0@>$@,!OE`Q`!X!P`&^48,!OE`S``X`,P@>$#
M((+@%#`;Y0,@@N`(,!OE`#"3Y0,@@N"8/9_E`S""X!`P"^4(,!OE!#"#X@@P
M"^4@,!OE8S&@X2`P"^40,!OEXRV@X2`0&^4<,!OE`Q"!X0PP&^4#$`'@(``;
MY1PP&^4#,`#@`S"!X0,@@N`8,!OE`R""X`@P&^4`,)/E`R""X#`]G^4#,(+@
M%#`+Y0@P&^4$,(/B"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A#!`;Y2`P&^4#
M$('A$#`;Y0,0`>`,`!OE(#`;Y0,P`.`#,('A`R""X!PP&^4#((+@"#`;Y0`P
MD^4#((+@R#R?Y0,P@N`8,`OE"#`;Y00P@^((,`OE$#`;Y6,QH.$0,`OE&#`;
MY>,MH.$0$!OE##`;Y0,0@>$4,!OE`Q`!X!``&^4,,!OE`S``X`,P@>$#((+@
M(#`;Y0,@@N`(,!OE`#"3Y0,@@N!@/)_E`S""X!PP"^4(,!OE!#"#X@@P"^44
M,!OE8S&@X10P"^4<,!OEXRV@X100&^40,!OE`Q"!X1@P&^4#$`'@%``;Y1`P
M&^4#,`#@`S"!X0,@@N`,,!OE`R""X`@P&^4`,)/E`R""X/@[G^4#,(+@(#`+
MY0@P&^4$,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A&!`;Y10P&^4#$('A
M'#`;Y0,0`>`8`!OE%#`;Y0,P`.`#,('A`R""X!`P&^4#((+@"#`;Y0`PD^4#
M((+@D#N?Y0,P@N`,,`OE"#`;Y00P@^((,`OE'#`;Y6,QH.$<,`OE##`;Y>,M
MH.$<$!OE&#`;Y0,0@>$@,!OE`Q`!X!P`&^48,!OE`S``X`,P@>$#((+@%#`;
MY0,@@N`(,!OE`#"3Y0,@@N`H.Y_E`S""X!`P"^4(,!OE!#"#X@@P"^4@,!OE
M8S&@X2`P"^40,!OEXRV@X2`0&^4<,!OE`Q"!X0PP&^4#$`'@(``;Y1PP&^4#
M,`#@`S"!X0,@@N`8,!OE`R""X`@P&^4`,)/E`R""X,`ZG^4#,(+@%#`+Y0@P
M&^4$,(/B"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A#!`;Y2`P&^4#$('A$#`;
MY0,0`>`,`!OE(#`;Y0,P`.`#,('A`R""X!PP&^4#((+@"#`;Y0`PD^4#((+@
M6#J?Y0,P@N`8,`OE"#`;Y00P@^((,`OE$#`;Y6,QH.$0,`OE&#`;Y>,MH.$0
M$!OE##`;Y0,0@>$4,!OE`Q`!X!``&^4,,!OE`S``X`,P@>$#((+@(#`;Y0,@
M@N`(,!OE`#"3Y0,@@N#P.9_E`S""X!PP"^4(,!OE!#"#X@@P"^44,!OE8S&@
MX10P"^4<,!OEXRV@X100&^40,!OE`Q"!X1@P&^4#$`'@%``;Y1`P&^4#,`#@
M`S"!X0,@@N`,,!OE`R""X`@P&^4`,)/E`R""X(@YG^4#,(+@(#`+Y0@P&^4$
M,(/B"#`+Y1@P&^5C,:#A&#`+Y2`P&^7C+:#A&!`;Y10P&^4#$('A'#`;Y0,0
M`>`8`!OE%#`;Y0,P`.`#,('A`R""X!`P&^4#((+@"#`;Y0`PD^4#((+@(#F?
MY0,P@N`,,`OE"#`;Y00P@^((,`OE'#`;Y6,QH.$<,`OE##`;Y>,MH.$<$!OE
M&#`;Y0,0@>$@,!OE`Q`!X!P`&^48,!OE`S``X`,P@>$#((+@%#`;Y0,@@N`(
M,!OE`#"3Y0,@@N"X.)_E`S""X!`P"^4(,!OE!#"#X@@P"^4@,!OE8S&@X2`P
M"^40,!OEXRV@X2`0&^4<,!OE`Q"!X0PP&^4#$`'@(``;Y1PP&^4#,`#@`S"!
MX0,@@N`8,!OE`R""X`@P&^4`,)/E`R""X%`XG^4#,(+@%#`+Y0@P&^4$,(/B
M"#`+Y0PP&^5C,:#A##`+Y10P&^7C+:#A#!`;Y2`P&^4#$('A$#`;Y0,0`>`,
M`!OE(#`;Y0,P`.`#,('A`R""X!PP&^4#((+@"#`;Y0`PD^4#((+@Z#>?Y0,P
M@N`8,`OE"#`;Y00P@^((,`OE$#`;Y6,QH.$0,`OE&#`;Y>,MH.$0$!OE##`;
MY0,0@>$4,!OE`Q`!X!``&^4,,!OE`S``X`,P@>$#((+@(#`;Y0,@@N`(,!OE
M`#"3Y0,@@N"`-Y_E`S""X!PP"^4(,!OE!#"#X@@P"^44,!OE8S&@X10P"^4<
M,!OEXRV@X1@0&^44,!OE`Q`AX!`P&^4#,"'@`R""X`PP&^4#((+@"#`;Y0`P
MD^4#((+@+#>?Y0,P@N`@,`OE"#`;Y00P@^((,`OE&#`;Y6,QH.$8,`OE(#`;
MY>,MH.$<$!OE&#`;Y0,0(>`4,!OE`S`AX`,@@N`0,!OE`R""X`@P&^4`,)/E
M`R""X-0VG^4#,(+@##`+Y0@P&^4$,(/B"#`+Y1PP&^5C,:#A'#`+Y0PP&^7C
M+:#A(!`;Y1PP&^4#$"'@&#`;Y0,P(>`#((+@%#`;Y0,@@N`(,!OE`#"3Y0,@
M@N!\-I_E`S""X!`P"^4(,!OE!#"#X@@P"^4@,!OE8S&@X2`P"^40,!OEXRV@
MX0P0&^4@,!OE`Q`AX!PP&^4#,"'@`R""X!@P&^4#((+@"#`;Y0`PD^4#((+@
M)#:?Y0,P@N`4,`OE"#`;Y00P@^((,`OE##`;Y6,QH.$,,`OE%#`;Y>,MH.$0
M$!OE##`;Y0,0(>`@,!OE`S`AX`,@@N`<,!OE`R""X`@P&^4`,)/E`R""X,PU
MG^4#,(+@&#`+Y0@P&^4$,(/B"#`+Y1`P&^5C,:#A$#`+Y1@P&^7C+:#A%!`;
MY1`P&^4#$"'@##`;Y0,P(>`#((+@(#`;Y0,@@N`(,!OE`#"3Y0,@@N!T-9_E
M`S""X!PP"^4(,!OE!#"#X@@P"^44,!OE8S&@X10P"^4<,!OEXRV@X1@0&^44
M,!OE`Q`AX!`P&^4#,"'@`R""X`PP&^4#((+@"#`;Y0`PD^4#((+@'#6?Y0,P
M@N`@,`OE"#`;Y00P@^((,`OE&#`;Y6,QH.$8,`OE(#`;Y>,MH.$<$!OE&#`;
MY0,0(>`4,!OE`S`AX`,@@N`0,!OE`R""X`@P&^4`,)/E`R""X,0TG^4#,(+@
M##`+Y0@P&^4$,(/B"#`+Y1PP&^5C,:#A'#`+Y0PP&^7C+:#A(!`;Y1PP&^4#
M$"'@&#`;Y0,P(>`#((+@%#`;Y0,@@N`(,!OE`#"3Y0,@@N!L-)_E`S""X!`P
M"^4(,!OE!#"#X@@P"^4@,!OE8S&@X2`P"^40,!OEXRV@X0P0&^4@,!OE`Q`A
MX!PP&^4#,"'@`R""X!@P&^4#((+@"#`;Y0`PD^4#((+@%#2?Y0,P@N`4,`OE
M"#`;Y00P@^((,`OE##`;Y6,QH.$,,`OE%#`;Y>,MH.$0$!OE##`;Y0,0(>`@
M,!OE`S`AX`,@@N`<,!OE`R""X`@P&^4`,)/E`R""X+PSG^4#,(+@&#`+Y0@P
M&^4$,(/B"#`+Y1`P&^5C,:#A$#`+Y1@P&^7C+:#A%!`;Y1`P&^4#$"'@##`;
MY0,P(>`#((+@(#`;Y0,@@N`(,!OE`#"3Y0,@@N!D,Y_E`S""X!PP"^4(,!OE
M!#"#X@@P"^44,!OE8S&@X10P"^4<,!OEXRV@X1@0&^44,!OE`Q`AX!`P&^4#
M,"'@`R""X`PP&^4#((+@"#`;Y0`PD^4#((+@##.?Y0,P@N`@,`OE"#`;Y00P
M@^((,`OE&#`;Y6,QH.$8,`OE(#`;Y>,MH.$<$!OE&#`;Y0,0(>`4,!OE`S`A
MX`,@@N`0,!OE`R""X`@P&^4`,)/E`R""X+0RG^4#,(+@##`+Y0@P&^4$,(/B
M"#`+Y1PP&^5C,:#A'#`+Y0PP&^7C+:#A(!`;Y1PP&^4#$"'@&#`;Y0,P(>`#
M((+@%#`;Y0,@@N`(,!OE`#"3Y0,@@N!<,I_E`S""X!`P"^4(,!OE!#"#X@@P
M"^4@,!OE8S&@X2`P"^40,!OEXRV@X0P0&^4@,!OE`Q`AX!PP&^4#,"'@`R""
MX!@P&^4#((+@"#`;Y0`PD^4#((+@!#*?Y0,P@N`4,`OE"#`;Y00P@^((,`OE
M##`;Y6,QH.$,,`OE%#`;Y>,MH.$0$!OE##`;Y0,0(>`@,!OE`S`AX`,@@N`<
M,!OE`R""X`@P&^4`,)/E`R""X*PQG^4#,(+@&#`+Y0@P&^4$,(/B"#`+Y1`P
M&^5C,:#A$#`+Y1@P&^7C+:#A%!`;Y1`P&^4#$"'@##`;Y0,P(>`#((+@(#`;
MY0,@@N`(,!OE`#"3Y0,@@N!4,9_E`S""X!PP"^4(,!OE!#"#X@@P"^44,!OE
M8S&@X10P"^4<,!OEXRV@X1@0&^44,!OE`Q`AX!`P&^4#,"'@`R""X`PP&^4#
M((+@"#`;Y0`PD^4#((+@_#"?Y0,P@N`@,`OE"#`;Y00P@^((,`OE&#`;Y6,Q
MH.$8,`OE(#`;Y>,MH.$<$!OE&#`;Y0,0(>`4,!OE`S`AX`,@@N`0,!OE`R""
MX`@P&^4`,)/E`R""X*0PG^4#,(+@##`+Y0@P&^4$,(/B"#`+Y1PP&^5C,:#A
M'#`+Y7`Q&^4`()/E##`;Y0,@@N!P,1OE`""#Y7`Q&^4$()/E(#`;Y0,@@N!P
M,1OE!""#Y7`Q&^4(()/E'#`;Y0,@@N!P,1OE"""#Y7`Q&^4,()/E&#`;Y0,@
M@N!P,1OE#""#Y7`Q&^40()/E%#`;Y0,@@N!P,1OE$""#Y0#0B^(`"+WH'O\O
MX=R\&X_6P6+*!+`MY0"PC>(,T$WB"``+Y0@P&^5@()_E`""#Y0@P&^58()_E
M!""#Y0@P&^50()_E"""#Y0@P&^5(()_E#""#Y0@P&^5`()_E$""#Y0@P&^4`
M(*#C%""#Y0@P&^4`(*#C&""#Y0@P&^4`(*#C7""#Y0#0B^(`"+WH'O\OX0$C
M16>)J\WO_MRZF'94,A#PX=+#`$@MZ02PC>(8T$WB$``+Y100"^48(`OE$#`;
MY10@D^48,!OE@S&@X0,P@N`(,`OE$#`;Y10@D^4(,!OE`P!2X00``)H0,!OE
M&#"3Y0$@@^(0,!OE&""#Y1`P&^4((!OE%""#Y1`P&^48()/E&#`;Y:,^H.$#
M((+@$#`;Y1@@@^40,!OE7#"3Y0``4^,V```*$#`;Y5PPD^5`,&/B##`+Y0P@
M&^48,!OE`P!2X0$``-H8,!OE##`+Y1`P&^4<((/B$#`;Y5PPD^4#((+@##`;
MY0(`H.$4$!OE`R"@X2WS_^L8(!OE##`;Y0(P8^`8,`OE##`;Y10@&^4#,(+@
M%#`+Y1`P&^5<()/E##`;Y0,@@N`0,!OE7""#Y1`P&^5<,)/E0`!3XQX``!H0
M`!OE@/?_ZPT``.H0,!OE'#"#X@,`H.$4$!OE0""@XQ+S_^L4,!OE0#"#XA0P
M"^48,!OE0#!#XA@P"^40`!OE<??_ZQ@P&^4_`%/C[O__RA`P&^4<((/B&#`;
MY0(`H.$4$!OE`R"@X0#S_^L0,!OE&"`;Y5P@@^4```#J``"@X0302^(`B+WH
M`$@MZ02PC>((T$WB"``+Y0P0"^4,`!OE6??_ZPPP&^4`,)/E(SR@X?\@`^((
M,!OE`"##Y0@P&^4!,(/B#"`;Y0`@DN4B**#A_R`"X@`@P^4(,!OE`C"#X@P@
M&^4`()+E(B2@X?\@`N(`(,/E"#`;Y0,P@^(,(!OE`""2Y?\@`N(`(,/E"#`;
MY00P@^(,(!OE!""2Y2(LH.'_(`+B`"##Y0@P&^4%,(/B#"`;Y00@DN4B**#A
M_R`"X@`@P^4(,!OE!C"#X@P@&^4$()+E(B2@X?\@`N(`(,/E"#`;Y0<P@^(,
M(!OE!""2Y?\@`N(`(,/E"#`;Y0@P@^(,(!OE"""2Y2(LH.'_(`+B`"##Y0@P
M&^4),(/B#"`;Y0@@DN4B**#A_R`"X@`@P^4(,!OE"C"#X@P@&^4(()+E(B2@
MX?\@`N(`(,/E"#`;Y0LP@^(,(!OE"""2Y?\@`N(`(,/E"#`;Y0PP@^(,(!OE
M#""2Y2(LH.'_(`+B`"##Y0@P&^4-,(/B#"`;Y0P@DN4B**#A_R`"X@`@P^4(
M,!OE#C"#X@P@&^4,()+E(B2@X?\@`N(`(,/E"#`;Y0\P@^(,(!OE#""2Y?\@
M`N(`(,/E"#`;Y1`P@^(,(!OE$""2Y2(LH.'_(`+B`"##Y0@P&^41,(/B#"`;
MY1`@DN4B**#A_R`"X@`@P^4(,!OE$C"#X@P@&^40()+E(B2@X?\@`N(`(,/E
M"#`;Y1,P@^(,(!OE$""2Y?\@`N(`(,/E!-!+X@"(O>@`2"WI!+"-XAC03>(8
M``OE'!`+Y1PP&^44,)/E##`+Y1PP&^48,)/E"#`+Y0PP&^6C,:#A/S`#XA`P
M"^4<,!OE'""#XA`P&^4#,(+@?R#@XP`@P^40,!OE`3"#XA`P"^40,!OE.`!3
MXQ(``-H<,!OE'""#XA`P&^4#((+@$#`;Y4`P8^("`*#A`!"@XP,@H.$,\O_K
M'``;Y:KV_^L<,!OE'#"#X@,`H.$`$*#C.""@XP3R_^L)``#J'#`;Y1P@@^(0
M,!OE`R""X!`P&^4X,&/B`@"@X0`0H.,#(*#A^?'_ZP@P&^4C/*#A_R`#XAPP
M&^54(,/E"#`;Y2,XH.'_(`/B'#`;Y54@P^4(,!OE(S2@X?\@`^(<,!OE5B##
MY0@P&^7_(`/B'#`;Y5<@P^4,,!OE(SR@X?\@`^(<,!OE6"##Y0PP&^4C.*#A
M_R`#XAPP&^59(,/E##`;Y2,TH.'_(`/B'#`;Y5H@P^4,,!OE_R`#XAPP&^5;
M(,/E&``;Y1P0&^4/___K!-!+X@"(O>@`2"WI!+"-X@C03>(`,*#C##`+Y0`P
MH.,(,`OEU?'_ZP`PH.$#`*#A__'_ZP`PH.$(,`OE"#`;Y0``4^,"```*"#`;
MY0`PD^4,,`OE##`;Y0,`H.$$T$OB`(B]Z`!(+>D$L(WB"-!-X@@`"^4``*#C
M4/+_ZP`PH.$`,)/E`P"@X<CQ_^L`,*#A`P"@X1GR_^L`,*#A"``;Y0,0H.'R
M!@#K`#"@X0``4^,C```:``"@XT#R_^L`,*#A`#"3Y0,`H.&X\?_K`#"@X0,`
MH.$)\O_K`#"@X1`PD^4/.@/B`0E3XPT```H``*#C,O+_ZP`PH.$`,)/E`P"@
MX:KQ_^L`,*#A`P"@X?OQ_^L`,*#A$#"3Y0\Z`^(*"E/C!P``&@@`&^4"$*#C
MHO'_ZP`PH.$``%/C`0``&@$PH.,```#J`#"@XP,`H.$$T$OB`(B]Z!!(+>D(
ML(WB/-!-XC@`"^4`,*#C'#`+Y0`PH.,8,`OE.#&?Y33`2^(#0*#A#P"TZ`\`
MK.@#`)3H`P",Z``PH.,0,`OE`#"@XQ0P"^4U``#J'``;Y?OR_^L`,*#A&#`+
MY1@P&^4``%/C`P``"A@P&^4`,-/E``!3XP,``!H<`!OE.!`;Y?OR_^LC``#J
M&``;Y3@0&^6=\?_K`#"@X0``4^,=```:.``;Y8/Q_^L`0*#AK#"?Y0`PD^4#
M`*#A?O'_ZP`PH.$#0(3@&``;Y7KQ_^L`,*#A`S"$X`(P@^(#`*#AI?'_ZP`P
MH.$0,`OE=""?Y6PPG^4`,)/E&!`;Y0`0C>40`!OE`A"@X3@@&^7K\?_K'``;
MY1`0&^76\O_K%#`;Y0$P@^(4,`OE%"`;Y2<PX.,"(:#A#!!+X@(@@>`#,(+@
M`#"3Y1PP"^4<,!OE`##3Y0``4^.]__\:"-!+XA"(O>A4]```6-$!`)CQ``!P
M2"WI$+"-XH'<3>(LT$WBF#>?Y1002^(#`('G`#"@XTPP"^4`,*#C2#`+Y0`P
MH.-$,`OE>#>?Y63`2^(/`)/H#P",Z&PWG^5\P$OB`^"@X0\`ON@/`*SH`P">
MZ`,`C.A4)Y_EB#!+X@<`DN@'`(/H2#>?Y4`P"^5$-Y_E/#`+Y0`PH.,X,`OE
M`#"@XS0P"^4`,*#C,#`+Y0`PH.,@,`OE(`>?Y8SR_^L`,*#A1#`+Y40P&^4`
M`%/C"0``"D0P&^4`,-/E``!3XP4```I$`!OE;___ZT0`&^5#\?_K`#"@X:\!
M`.H7___K`#"@X30P"^4T,!OE``!3XQ\``!H`,*#C5#`+Y0T``.I(`!OE<O+_
MZP`PH.%$,`OE1#`;Y0``4^,#```*1``;Y2_Q_^L`,*#A-#`+Y50P&^4!,(/B
M5#`+Y30P&^4``%/C"P``&E0@&^5S,.#C`B&@X13`2^("((S@`S""X``PD^5(
M,`OE2#`;Y0`PT^4``%/CXO__&C0P&^4``%/C`@``&CPVG^4T,`OE%P``ZC0P
M&^50,`OE$```Z@OQ_^L`,*#A`""3Y5`P&^4`,-/E@S"@X0,P@N"P,-/A"#`#
MX@``4^,"```:4#`;Y5\@H.,`(,/E4#`;Y0$P@^)0,`OE4#`;Y0`PT^4``%/C
MZO__&@`PH.-4,`OE$@``ZD@`&^4T\O_K`#"@X40P"^5$,!OE``!3XP@```I$
M`!OEW_[_ZP`PH.$``%/C`P``"D0`&^7L\/_K`#"@X4PP"^54,!OE`3"#XE0P
M"^5,,!OE``!3XPL``!I4(!OE9S#@XP(AH.$4$$OB`B"!X`,P@N``,)/E2#`+
MY4@P&^4`,-/E``!3X]W__QH`,*#C5#`+Y0L``.I$`!OEP?[_ZP`PH.$``%/C
M`P``"D0`&^7.\/_K`#"@X4PP"^54,!OE`3"#XE0P"^5,,!OE``!3XPL``!I4
M(!OE3S#@XP(AH.$4P$OB`B",X`,P@N``,)/E1#`+Y40P&^4`,-/E``!3X^3_
M_QI,`!OED?#_ZP!`H.%``!OECO#_ZP`PH.$#0(3@-``;Y8KP_^L`,*#A`T"$
MX#P`&^6&\/_K`#"@X0,PA.`!.X/B(#`+Y2`P&^4#`*#AK_#_ZP`PH.$P,`OE
M<"2?Y7`TG^4`,)/E0!`;Y0`0C>4T$!OE!!"-Y3``&^4"$*#A3"`;Y?/P_^LP
M`!OE2!2?Y0_P_^M$!)_ET/'_ZP`PH.%$,`OE1#`;Y0``4^,+```*_#.?Y100
M2^(#,)'G`$"3Y40`&^6)\/_K`#"@X00`H.$#$*#AZO+_ZP`PH.$X,`OE.#`;
MY0``4^,$```:P#.?Y10@2^(#,)+G`#"3Y3@P"^6>]/_K`#"@X0``4^.@```:
M.``;Y0`0H.-<\/_K`#"@X2PP"^4L,!OE``!3XY@```H",*#C`#"-Y2P`&^41
M(.#C`##@XV_P_^N!/$OB%#!#XBP`&^4#$*#A!B"@XR'P_^M\,Y_E%,!+X@,P
MW.<``%/C0@``&F@CG^4!,*#C%!!+X@(@@>`#,(+@`##3Y4,`4^,Z```:2".?
MY0(PH.,4P$OB`B",X`,P@N``,-/E00!3XS(``!HH(Y_E`S"@XQ002^("(('@
M`S""X``PT^5#`%/C*@``&@@CG^4$,*#C%,!+X@(@C.`#,(+@`##3Y4@`4^,B
M```:Z"*?Y04PH.,4$$OB`B"!X`,P@N``,-/E10!3XQH``!H",*#C`#"-Y2P`
M&^4Y(.#C`##@XS;P_^N!/$OB%#!#XBP`&^4#$*#A*2"@X^CO_^LP`!OE`?#_
MZP`PH.$P(!OE`P""X(@2G^5T,I_E`""3Y8$\2^(4,$/B/,`;Y0#`C>5W\/_K
M``"@X8,``.I%/TOB`P"@X6W\_^L&``#J12]+XH$\2^(4,$/B`@"@X0,0H.$H
M(!OEB?S_ZX$\2^(4,$/B+``;Y0,0H.$"*:#CR.__ZP`PH.$H,`OE*#`;Y0``
M4^/M___*+``;Y?3O_^N!/$OB%#!#XA0P0^)%+TOB`P"@X0(0H.%P_?_K`#"@
MXR0P"^40``#J)#`;Y8,PH.$#(*#AM#!+X@(P@^#($9_E)"`;Y<0!G^44P$OB
M``",X`(@@.``(-+E`P"@X47P_^LD,!OE`3"#XB0P"^4D,!OE$P!3X^O__]H`
M,*#CC#!+Y3``&^6Z[__K`#"@X3`@&^4#`(+@;!&?Y5@QG^4`()/EM#!+XCS`
M&^4`P(WE,?#_ZSX``.H`,*#C'#`+Y3``&^6K[__K`#"@X1@P"^5``9_E0!&?
MY17Q_^LP`!OEI.__ZP`PH.$P(!OE`V""X"A1G^4`,9_E`$"3Y>CO_^L`,*#A
M/"`;Y0`@C>4&`*#A!1"@X00@H.$7\/_K&0``ZC`@&^48,!OE`S""X``@H.,`
M(,/E,``;Y8[O_^L`,*#A,"`;Y0-@@N#44)_EJ#"?Y0!`D^72[__K`#"@X1P@
M&^4!((+B'"`+Y1P@&^4`((WE/"`;Y00@C>4&`*#A!1"@X00@H.'\[__K,``;
MY6P0G^48[__K`#"@X0$`<^,$```:\N__ZP`PH.$`,)/E$0!3X]K__PHT`)_E
M,!`;Y=SP_^LP`!OEO/W_ZS`P&^4#`*#A$-!+XG"(O>CD?O__M/,``.#S```,
M]```A/(``(SR``!X\0``D/(``)CR``!4T0$`[0$``*3R````?___K/(``+SR
M``#L?O__O/$``%SR``#$\@``T/(``!!(+>D(L(WBA-!-XH@`"^4`,*#C%#`+
MY8@P&^4``%/C50``"H@P&^4`,-/E``!3XU,```J(`!OE[>[_ZP`PH.$<,`OE
M'#`;Y0``4^,]```:3```ZA@P&^43,(/B`P"@X2@1G^6Q[__K`#"@X0``4^,U
M```*&#`;Y1,P@^(#`*#A#!&?Y:GO_^L`,*#A``!3XRT```J(`!OE+.__ZP!`
MH.$8,!OE$S"#X@,`H.$G[__K`#"@X0,PA.`",(/B$#`+Y1`P&^4#`*#A4.__
MZP`PH.$4,`OEO""?Y1@P&^43,(/B%``;Y0(0H.&((!OEF.__ZQ0@&^6$,$OB
M`@"@X0,0H.$G!`#K`#"@X0$`<^,&```*=#`;Y0\Z`^(!"5/C`@``&A0`&^6U
M___K`0``ZA0`&^4)[__K%``;Y>;N_^L`,*#C%#`+Y0```.H``*#A'``;Y5OO
M_^L`,*#A&#`+Y1@P&^4``%/CNO__&AP`&^45[__KB``;Y2OO_^L"``#J``"@
MX0```.H``*#A"-!+XA"(O>B4\0``X/(``.3R````2"WI!+"-XA#03>(0``OE
M$``;Y67R_^L`,*#A##`+Y0P`&^5!\O_K`#"@X0@P"^4J\__K`#"@X0``4^,/
M```*$#`;Y0``4^,,```*$#`;Y0`PT^4``%/C"```"@@`&^4@$)_EY^[_ZP`@
MH.$(,!OE`P!2X0$``!H0`!OE>/__ZP302^(`B+WHA/(``!!(+>D(L(WB#-!-
MXA`0"^4``*#C+^__ZP`PH.$`,)/E`P"@X:?N_^L`,*#A`P"@X5GN_^L`,*#A
M`#"3Y01`D^4``*#C(^__ZP`PH.$`,)/E`P"@X9ON_^L`,*#A`P"@X6ON_^L`
M,*#A`##3Y?\P`^(8,,3E``"@XQ;O_^L`,*#A`#"3Y0,`H.&.[O_K`#"@X0,`
MH.%`[O_K`#"@X0`PD^4$0)/E``"@XPKO_^L`,*#A`#"3Y0,`H.&"[O_K`#"@
MX0,`H.%5[O_K`#"@X0`PD^6P,=/A@SN@X:,[H.$#.*#A(SB@X;HQQ.$``*#C
M^>[_ZP`PH.$`,)/E`P"@X7'N_^L`,*#A`P"@X2/N_^L`,*#A`#"3Y01`D^4`
M`*#C[>[_ZP`PH.$`,)/E`P"@X67N_^L`,*#A`P"@X>01G^4`(*#CS.[_ZP`P
MH.$<,(3E``"@X^#N_^L`,*#A`#"3Y0,`H.%8[O_K`#"@X0,`H.$*[O_K`#"@
MX0`PD^4$0)/E``"@X]3N_^L`,*#A`#"3Y0,`H.%,[O_K`#"@X0,`H.$9[O_K
M`#"@X0`PD^4@,(3E``"@X\CN_^L`,*#A`#"3Y0,`H.%`[O_K`#"@X0,`H.'R
M[?_K`#"@X0`PD^4$0)/E``"@X[SN_^L`,*#A`#"3Y0,`H.$T[O_K`#"@X0,`
MH.&"[O_K`#"@X0`PD^4``%/C#```"@``H..O[O_K`#"@X0`PD^4#`*#A)^[_
MZP`PH.$#`*#A=>[_ZP`PH.$`,)/E;#"3Y0```.H`,*#C)#"$Y0``H..@[O_K
M`#"@X0`PD^4#`*#A&.[_ZP`PH.$#`*#ARNW_ZP`PH.$`,)/E!#"3Y0`@H.,H
M((/E``"@XY+N_^L`,*#A`#"3Y0,`H.$*[O_K`#"@X0,`H.&\[?_K`#"@X0`P
MD^4$,)/E`""@XRP@@^4``*#CA.[_ZP`PH.$`,)/E`P"@X?SM_^L`,*#A`P"@
MX:[M_^L`,*#A`#"3Y01`D^4``*#C>.[_ZP`PH.$`,)/E`P"@X?#M_^L`,*#A
M`P"@X5_N_^L`,*#A`#"3Y3`PA.4(T$OB$(B]Z(SR````2"WI!+"-X@C03>((
M$`OE``"@XV7N_^L`,*#A`#"3Y0,`H.'=[?_K`#"@X0,`H.$`$.#CT.W_ZP``
MH.-;[O_K`#"@X0`PD^4#`*#AT^W_ZP`PH.$#`*#A#!"?Y0`@H.-J[O_K!-!+
MX@"(O>B8W```$$@MZ0BPC>(LT$WB,!`+Y0`PH.,8,`OE``"@XT?N_^L`,*#A
M`#"3Y0,`H.&_[?_K`#"@X0,`H.'"[?_K`#"@X0$@H.,`(,/E+`:?Y3+O_^L`
M,*#A%#`+Y10P&^4``%/C"```"A0P&^4`,-/E,0!3XP0``!H4,!OE`3"#X@`P
MT^4``%/C````"I[Q_^L``*#C*N[_ZP`PH.$`,)/E`P"@X:+M_^L`,*#A`P"@
MX<P5G^4!(*#C"S"@XW[M_^L`,*#A+#`+Y2PP&^4``%/C;```"BPP&^4,,)/E
M&#"3Y2@P"^4!,*#C'#`+Y3\``.H``*#C$N[_ZP`PH.$`,)/E`P"@X8KM_^L`
M,*#A`R"@X1PP&^4!,$/B`@"@X2@0&^4#(*#A`#"@XZOM_^L`,*#A)#`+Y20P
M&^4``%/C,0``"D`UG^4`()/E'#`;Y0,QH.$#,(+@`$"3Y20P&^4`,)/E"#"3
MY0$[`^(``%/C`P``"B0P&^4`,)/E##"3Y0\``.H``*#C[NW_ZP`PH.$`,)/E
M`P"@X6;M_^L`,*#A`R"@X20P&^4`,)/E`@"@X0,0H.$`(*#C`C"@X_SM_^L`
M,*#A!`"@X0,0H.'I[?_K`#"@X0``4^,-```:&#`;Y0$P@^(8,`OE'#`;Y0$P
M@^(<,`OEE#2?Y0`PD^4<(!OE`P!2X;K__[H"``#J``"@X0```.H``*#A<#2?
MY0`PD^4!($/B&#`;Y0,`4N$6```:`3"@XQPP"^4.``#J``"@X\#M_^L`,*#A
M`#"3Y0,`H.$X[?_K`#"@X0,`H.$H$!OE$^W_ZP`PH.$@,`OE'#`;Y0$P@^(<
M,`OE$#2?Y0`PD^4<(!OE`P!2X>O__[H``*#CK.W_ZP`PH.$`,)/E`P"@X23M
M_^L`,*#A`P"@X>`3G^4!(*#C!3"@XP#M_^L`,*#A+#`+Y2PP&^4``%/C(P``
M"@``H..;[?_K`#"@X0`PD^4#`*#A$^W_ZP`PH.$#(*#A+#`;Y0PPD^4`,)/E
M`@"@X0,0H.&,(Y_E\NS_ZRPP&^4,,)/E`#"3Y0@PD^4!-0/B``!3XPT```H`
M`*#CA>W_ZP`PH.$`,)/E`P"@X?WL_^L`,*#A`R"@X2PP&^4,,)/E`#"3Y0(`
MH.$#$*#A-^W_ZP``H.-W[?_K`#"@X0`PD^4#`*#A[^S_ZP`PH.$#`*#A%!.?
MY0$@H.,%,*#CR^S_ZP`PH.$L,`OE+#`;Y0``4^,J```*`#"@XQ`P"^7L`I_E
M6^[_ZP`PH.$0,`OE$#`;Y0``4^,/```*``"@XUWM_^L`,*#A`#"3Y0,`H.'5
M[/_K`#"@X0,@H.$L,!OE##"3Y0`PD^4"`*#A`Q"@X1`@&^6T[/_K$0``Z@``
MH.--[?_K`#"@X0`PD^4#`*#AQ>S_ZP`PH.$#$*#A+#`;Y0PPD^4`()/E4#*?
MY0`PD^4`,)/E`0"@X0(0H.$#(*#AF^W_ZP``H.,[[?_K`#"@X0`PD^4#`*#A
ML^S_ZP`PH.$#`*#AMNS_ZP`PH.$`(*#C`"##Y0``H.,O[?_K`#"@X0`PD^4#
M`*#AI^S_ZP`PH.$#`*#A,>W_ZP`PH.$`(*#C`""#Y>P!G^4:[O_K`""@X>0Q
MG^4`((/EW#&?Y0`PD^4``%/C3P``&K`QG^4`,)/E`P"@X5C[_^L`(*#AN#&?
MY0`@@^4L,!OE##"3Y0`PD^4(,)/E`3L#X@``4^,$```*+#`;Y0PPD^4`,)/E
M##"3Y1```.H``*#C!^W_ZP`PH.$`,)/E`P"@X7_L_^L`,*#A`R"@X2PP&^4,
M,)/E`#"3Y0(`H.$#$*#A`""@XP(PH.,4[?_K`#"@X2`AG^4`()+E`P"@X0(0
MH.%:[/_K`#"@X1PP"^4$,9_E`#"3Y0!`D^4L,!OE##"3Y0`PD^4(,)/E`3L#
MX@``4^,$```*+#`;Y0PPD^4`,)/E##"3Y1```.H``*#CX.S_ZP`PH.$`,)/E
M`P"@X5CL_^L`,*#A`R"@X2PP&^4,,)/E`#"3Y0(`H.$#$*#A`""@XP(PH./M
M[/_K`#"@X:0`G^4$$*#A`R"@X1PP&^6E[/_KC#"?Y0`PD^4#`*#AB!"?Y?OK
M_^L`,*#A'#`+Y1PP&^4``%/C#P``"APP&^41`%/C#```"APP&^4!`'/C"0``
M"C`PG^4`,)/E`""3Y4`PG^4`,)/E1`"?Y0(0H.$#(*#A'#`;Y8OL_^L(T$OB
M$(B]Z*#Q``#L\@``C-$!`(C1`0#T\@``^/(```#S``"$\0``>/$``(31`0`$
M\P``[0$``#3S````2"WI!+"-X@C03>(``*#CGNS_ZP`PH.$`,)/E`P"@X1;L
M_^L`,*#A`P"@X=_L_^L``*#CE>S_ZP`PH.$`,)/E`P"@X0WL_^L`,*#A)""?
MY0`@C>4`(*#C!""-Y0,`H.$4$)_E%""?Y0@PG^45[/_K!-!+X@"(O>B,\@``
MA/,``##@```P2"WI#+"-XB#03>(8``OE'!`+Y2`@"^48$$OB'"!+XB`P2^(!
M`*#A`A"@X0,@H.%R[/_KF`.?Y9@3G^64(Y_E\0``ZP``H./<Z__K`#"@X0`P
MT^4``%/C&0``&M3K_^L`(*#A<#.?Y0`@@^5H,Y_E`#"3Y0``4^,!```:`0"@
MXW#L_^M0,Y_E`#"3Y0,`H.'NZ__K``"@XUOL_^L`,*#A`#"3Y0,`H.'3Z__K
M`#"@X0,`H.$P[/_K`#"@X0`@H.,`(,/E``"@XT_L_^L`,*#A`#"3Y0,`H.''
MZ__K`#"@X0,`H.%+[/_K`#"@X0`@T^4"((+C_R`"X@`@P^4``*#C0>S_ZP`P
MH.$`,)/E`P"@X;GK_^L`,*#A`P"@X3WL_^L`,*#A`"#3Y0$@@N/_(`+B`"##
MY1@P&^4%,(/B`P"@X9`!`.L`,*#A`4"@X0,`H.$$$*#A`""@XP`PH./>``#K
M`#"@X0%`H.$`(*#C`E"@X0,`H.$$$*#ADS^/X@P`D^@%`@#K`#"@X0``4^,!
M```*`3"@XP-0H.'_,`7B``!3XP$```HT`I_E\.O_ZQ@P&^4%,(/B`S&@X0,`
MH.'TZ__K`#"@X0,@H.$4,I_E`""#Y0PRG^4`,)/E'"`;Y0`@DN4`((/E^#&?
MY0`PD^4$,(/B\"&?Y0`@@^7D,9_E`#"3Y0@P@^+@(9_E`""#Y=PQG^4#(*#C
M`""#Y<0QG^4`()/ER#&?Y0`PD^4#,:#A`S""X+PAG^4`((/EL#&?Y0`PD^4!
M((/BI#&?Y0`@@^4!,*#C$#`+Y1$``.J$,9_E`""3Y8@QG^4`$)/E$#`;Y0,P
M@>`!,$/B`S&@X0,P@N`<$!OE$"`;Y0(AH.$"(('@`""2Y0`@@^40,!OE`3"#
MXA`P"^48,!OE$"`;Y0,`4N'I__^Z+#&?Y0`@D^48$!OE+#&?Y0`PD^4#,('@
M`3!#X@,QH.$#,(+@`""@XP`@@^7X,)_E`!"3Y1@@&^4`,9_E`#"3Y0,P@N`!
M($/BY#"?Y0`PD^4``*#C``"-Y0$`H.'D$)_E_>K_ZP`PH.$4,`OE%#`;Y0``
M4^,%```:K#"?Y0`PD^4#`*#A#.O_ZP`PH.$4,`OEE#"?Y0`PD^4#`*#A7>O_
MZZ0`G^6C[/_K`#"@X0``4^,0```:E#"?Y0`PD^4``%/C!```&H@`G^6:[/_K
M`""@X7@PG^4`((/E<#"?Y0`PD^4``%/C`P``"F`PG^4`,)/E`P"@X3_\_^LL
M,)_E`#"3Y0,`H.'+ZO_K&.O_ZQ0P&^4#`*#A#-!+XC"(O>@``(#____/09R7
M``"(E@``@-$!`&S1`0",T0$`G/,``'3T``"(T0$`H/,``.#F``"P\0``A-$!
M`'CQ`````*#A'#"?Y1S`G^4#,(_@!$`MY0Q`D^`$,*`!##"3%Q``O>A,Z__J
M@.0``%`!```>_R_A\$4MZ0303>(!@*#A`G"@X0"@H.&4ZO_K2!"?Y4@PG^5(
M()_E`S!AX`(@C^!#4;#A`2""X`D```H"8*#A`$"@XPH`H.$($*#A!R"@X0_@
MH.$$\9;G`4"$X@4`5.'W__\Z!-"-XO"%O>CD_O__Z/[__S#D```!(*#A`!"@
MX0,`H.,*Z__J`2"@X0`0H.$#`*#C.>O_Z@(1(>(```#J`C$CXC!`+>F!0*#A
M@U"@X04`-.$"`#`!`,"4$0+`E1'$RO`1Q<KP$7D```JD2J#AI5ITX`!09;(&
M``#:!4"$X`(@(.`#,"'@```BX`$0(^`"("#@`S`AX#8`5>,P@+V(`@$1XP$6
MH.$!QJ#C(1:,X0$```H``'#B`!#AX@(!$^,#-J#A(S:,X0$```H`('+B`##C
MX@4`-.%7```*`4!$XB#@=>(%``"Z$LZ@X3(%D.``$*'B$PZ0X%,5L>`&``#J
M(%!%XB#@CN(!`%+C$\Z@X0+`C"-3!9#@PQ^QX`)1`>("``!:`,!\X@``\.(`
M$.'B`091XPX``#H"!E'C!@``.J$0L.%@`+#A;,"@X0%`A.*$*J#A`05RXU4`
M`"H"`5SCH,"P`0``L.($&J'@!1"!X3"`O>B,P+#A``"PX`$0H>`!!A'C`4!$
MXO/__QH``#'C`!"@`0``H`,1/V_A(#"#`@LP0^(@(%/B!P``J@P@DN($``#:
M%,""X@P@8N(1#*#A,1*@X00``.H4((+B(,!BTA$2H.$P'('1$`*@T0-`5.`$
M&H&@!1"!H3"`O:@$0.#A'T!4X@T``*H,0)3B!0``RA1`A.(@(&3B,`2@X1$"
M@.$Q%(7A,("]Z`Q`9.(@(&3B,`*@X1$$@.$%$*#A,("]Z#$$H.$%$*#A,("]
MZ```-.,!-B/B`18A`@%`A`(!4$42H?__ZL3*\.'%RO`1&```"@4`-.$"`#`!
M`P``"@#`E.$#$*`!`@"@`3"`O>@#`#'A`!"@$P``H!,P@+T8I,JPX0,``!J`
M`+#A`1"QX`(1@2,P@+WH`464X@$6@3(P@+TX`E$!XG\4A>,/%H'C``"@XS"`
MO>C$RO#A`Q"@$0(`H!'%RO`!`3"@$0`@H!$!1I#A`U:2`0,`,0$"%X$3,("]
MZ```,.,`$*`#'O\O`3!`+>D!2Z#C,D"$X@!0H.,`$*#CG?__Z@``,.,`$*`#
M'O\O`3!`+>D!2Z#C,D"$X@)1$.(``&!"`!"@XY/__^J`(+#APA&@X6$0H.$"
M#J#A_S02$O\$,Q,.$R$2'O\O$0``,N/_!#,3'O\O`3!`+>D.3:#C`E$!X@(1
MP>.#___J`2"0X1[_+P$P0"WI`%"@XP8``.H!()#A'O\O`3!`+>D"41'B`0``
M6@``<.(`$.'B`4N@XS)`A.(AR[#A7/__"@,@H..LP;#A`R""$JS!L.$#(((2
MK"&"X"`P8N(0PZ#A,`*@X1$#@.$Q$J#A`D"$X$___^H`P.#C`@``Z@'`H.,`
M``#J`<"@XP3`#>6!P*#AS,KPX8/`H.',RO`1#0``"H'`D.&#P)(!`P`Q$0(`
M,`$``*`#'O\O`0``<.,#`#'A`P!140(`4`'##Z`APP_@,0$`@.,>_R_A@<"@
MX<S*\.$!```:`<:0X00``!J#P*#AS,KPX>G__QH#QI+AY___"@0`'>4>_R_A
M`,"@X0(`H.$,(*#A`<"@X0,0H.$,,*#A____Z@%`+>G5___K``!0XP``<$,!
M@+WH".`MY?C__^L!`*`#``"@$PCPG>0(X"WE\___ZP$`H#,``*`C"/"=Y`C@
M+>7N___K`0"@DP``H(,(\)WD".`MY>+__^L!`*"3``"@@PCPG>0(X"WEW?__
MZP$`H#,``*`C"/"=Y`3@+>4$T$WB!-"-X@"`O>@!``(`<&5R;'AS:2YC````
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`"]P<F]C+W-E;&8O97AE```O
M````.@```"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!
M344`````+@```"5S)7,E<P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!4D=#
M`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!
M3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("``````<&%R+0``````````4UE35$5-```E<R5S
M)7,E<P````!0051(`````"5S8V%C:&4M)7,E<P`````E,#)X`````"5S=&5M
M<"TE=25S`"5S=&5M<"TE=2TE=25S```N+@``)7,O)7,```!!4D=6`````!@`
M``!P97)L`````#`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B
M;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP
M;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@```$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"UE```M+0``0SI<5$5-
M4``O=&UP`````*3S``"L\P``E/$``(SR``!435!$25(``%1%35!$25(`5$5-
M4`````!435``(/(``,3S``#,\P``U/,``-SS``",\@``55-%4@````!54T52
M3D%-10````#X\P```/0``(SR``!,1%],24)205)97U!!5$@`3$E"4$%42`!,
M24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@````8]```*/0``##T
M``"D\@``0/0``(SR``!P87(N<&P``",A+W5S<B]B:6XO<&5R;`H*979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P
M87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO
M9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN
M92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z
M.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER
M92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O
M<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P
M<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@
M4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@
M9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@
M;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@
M("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I
M;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE
M;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@
M8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@
M;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@
M("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@
M("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%
M35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&
M1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@
M("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@
M("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K
M"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO
M9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L
M;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*
M?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A
M<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N
M9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB
M4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@
M("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y
M<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%2
M1U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N
M9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I
M8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U
M;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE
M('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(
M*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A
M9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!
M4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U
M9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG
M(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI
M<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@
M("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI
M.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D
M97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D
M;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E
M(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M
M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@
M("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P
M96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@
M("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^
M("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L
M($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@
M("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@
M("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@
M("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H
M)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@
M("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N
M86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@
M;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@
M('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@
M>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN
M9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE
M<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO
M860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E
M(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@
M("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@
M("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T
M92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*
M"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N
M="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@
M9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N
M<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@
M("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@
M("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R
M"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@;7D@0&%D9%]T
M;U]I;F,["B`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`D05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@
M("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I
M;F,L("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2![
M"B`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G
M*2!["B`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I
M=&4G.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@
M("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@
M("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G5"<I('L*("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@
M("!]"@H@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PH@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@
M("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X
M:70["B`@("`@("`@?0H@("`@?0H*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*
M(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O
M=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]
M"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*
M("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@
M("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`]
M(&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T
M<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F
M:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D
M:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@
M9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@
M(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@
M("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L
M"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@
M("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@
M<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G
M.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD
M968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[
M>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@
M("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I
M.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T
M:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@
M("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H
M)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.
M0SL*"B`@("`@("`@:68@*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[
M7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S
M="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO
M;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:
M;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I
M9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@
M("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@
M=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F
M86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@
M("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O
M9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L
M<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N
M=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED
M.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@
M(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@
M("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@
M("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@
M+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@
M("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@
M('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*
M("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@
M;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I
M.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N
M86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D
M9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@
M(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM
M;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A
M;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G
M;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O
M9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@
M("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*
M("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@
M("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P
M=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B![
M"B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@
M("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@
M("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@
M("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE
M=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N
M(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D
M;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@
M(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C
M=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S
M<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#`R
M"@I?7T5.1%]?"@````1,_W\!````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!@
MF@``1)H````````!`````0````$```"_`@```0```,H"```!````U`(```$`
M```C`P```0```#P$```,````#)8```T````4\0``&0```.3.`0`;````!```
M`!H```#HS@$`'`````0````$````B($```4```!TC```!@```/2$```*````
MV`4```L````0````%0`````````#`````-`!``(```!X`@``%````!$````7
M````E),``!$```!\DP``$@```!@````3````"````/[__V\\DP``____;P(`
M``#P__]O3)(`````````````````````````````````````````````````
M`````````````````/#.`0```````````""6```@E@``()8``""6```@E@``
M()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@
ME@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6
M```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8`
M`""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``
M()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6```@
ME@``()8``""6```@E@``()8``""6```@E@``()8``""6```@E@``()8``""6
M```@E@``()8``""6```@E@``()8``""6``````````````````!@\0``9/$`
M`/____]L]```;5D``$$G````865A8FD``1T````%-50`!@,(`0D!"@(2!!0!
M%0$7`Q@!&@(`1T-#.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``
M1T-#.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U
M;G1U(#0N-"XP+3!U8G5N='4U*2`T+C0N,```1T-#.B`H56)U;G1U(#0N-"XP
M+3!U8G5N='4U*2`T+C0N,```1T-#.B`H56)U;G1U(#0N-"XP+3!U8G5N='4U
M*2`T+C0N,```1T-#.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``
M1T-#.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U
M;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS
M+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N-"XP+3!U8G5N='4U
M*2`T+C0N,```1T-#.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN
M`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED
M>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+D%232YA='1R:6)U=&5S`"YC;VUM96YT
M````````````````````````````````````````````````````````"P``
M``$````"````5($``%0!```3```````````````!`````````!,````'````
M`@```&B!``!H`0``(```````````````!``````````A````!0````(```"(
M@0``B`$``&P#```$``````````0````$````)P````L````"````](0``/0$
M``"`!P``!0````$````$````$````"\````#`````@```'2,``!T#```V`4`
M`````````````0`````````W````____;P(```!,D@``3!(``/`````$````
M``````(````"````1````/[__V\"````/),``#P3``!`````!0````(````$
M`````````%,````)`````@```'R3``!\$P``&`````0`````````!`````@`
M``!<````"0````(```"4DP``E!,``'@"```$````"P````0````(````90``
M``$````&````#)8```P6```4```````````````$`````````&`````!````
M!@```""6```@%@``R`,`````````````!`````0```!K`````0````8```#H
MF0``Z!D``"Q7``````````````@`````````<0````$````&````%/$``!1Q
M```0```````````````$`````````'<````!`````@```"3Q```D<0``P%P`
M````````````!`````````!_`````0``<((```#D30$`Y,T```@````,````
M``````0`````````B@````$````"````[$T!`.S-```$```````````````$
M`````````)0````.`````P```.3.`0#DS@``!```````````````!```````
M``"@````#P````,```#HS@$`Z,X```0```````````````0`````````K```
M``$````#````[,X!`.S.```$```````````````$`````````+$````&````
M`P```/#.`0#PS@``$`$```4`````````!`````@```"Z`````0````,`````
MT`$``-```$P!``````````````0````$````OP````$````#````3-$!`$S1
M```<```````````````$`````````,4````(`````P```&C1`0!HT0``+!``
M````````````"`````````#*`````P``<```````````:-$``"@`````````
M``````$`````````V@````$``````````````)#1``",`0`````````````!
M``````````$````#```````````````<TP``XP```````````````0``````
M```!````()8```````````L`!````#"6```````````+``$````TE@``````
,````"P``)&$`)&0`
